# Changelog for decorate-me

Adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html)
and [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).


## [0.2.0] - 2021-01-05

### Removed:
- Support for Python 3.7

### Fixed:
- Upgraded build


## [0.1.0] - 2020-05-18

### Added:
- Main code.
